@@ -1,5 +1,7 @@
 from BaseHTTPServer import BaseHTTPRequestHandler, HTTPServer
 import threading
+
+
 class HTTPTestServer(threading.Thread):
     
     def __init__(self):
@@ -13,35 +15,24 @@ class HTTPTestServer(threading.Thread):
         return self._stop.isSet()
     
     class MyHandler(BaseHTTPRequestHandler):
-    
-        def do_GET(self):
+        def send_headers(self):
             self.send_response(200)
             self.send_header('Content-type', 'text/html')
             self.end_headers()
-            self.wfile.write(" ".join([self.command, self.path]))
+
+        def handle_http_request(self):
+            self.send_headers()
+            self.wfile.write(" ".join([
+                self.command,
+                self.path
+                ]))
             return
-    
-        def do_POST(self):
-            self.send_response(200)
-            self.send_header('Content-type', 'text/html')
-            self.end_headers()
-            self.wfile.write(" ".join([self.command, self.path]))
-            return
-    
-        def do_PUT(self):
-            self.send_response(200)
-            self.send_header('Content-type', 'text/html')
-            self.end_headers()
-            self.wfile.write(" ".join([self.command, self.path]))
-            return
-        
-        def do_DELETE(self):
-            self.send_response(200)
-            self.send_header('Content-type', 'text/html')
-            self.end_headers()
-            self.wfile.write(" ".join([self.command, self.path]))
-            return
-        
+
+        def __getattr__(self, item):
+            if item.startswith("do_"):
+                return self.handle_http_request
+            raise AttributeError("'%s' object has no attribute '%s'" % (type(self), item))
+
     def run(self):
         server = HTTPServer(('', 8880), HTTPTestServer.MyHandler)
         while not self.stopped():
